@@ -10,20 +10,19 @@
 #'       an \sQuote{xml} or \sQuote{json} file type.
 #' @export
 #' @examples 
-#' \dontrun{
-#' ex.dir <- auto_detect_apsimx_examples()
-#' apsimx_filetype("Barley", src.dir = ex.dir) 
-#' apsimx_filetype("Chicory", src.dir = ex.dir) 
-#' apsimx_filetype("Oats", src.dir = ex.dir)                               
-#' apsimx_filetype("Maize", src.dir = ex.dir)
-#' apsimx_filetype("Sugarcane", src.dir = ex.dir)
+#' \donttest{
+#' extd.dir <- system.file("extdata", package = "apsimx")
+#' apsimx_filetype("Wheat.apsimx", src.dir = extd.dir) 
 #' }
 #' 
 
 apsimx_filetype <- function(file = "", src.dir = "."){
   
   
-  file.names <- dir(path = src.dir, pattern=".apsimx$",ignore.case=TRUE)
+  file.names <- dir(path = src.dir, pattern=".apsimx$", ignore.case=TRUE)
+  file.names.c <- dir(path = src.dir, pattern=".apsim$", ignore.case=TRUE)
+  ## print(file.names.c)
+  # file.names <- c(file.names.x, file.names.c)
   
   if(length(file.names)==0){
     stop("There are no .apsimx files in the specified directory to test.")
@@ -31,7 +30,7 @@ apsimx_filetype <- function(file = "", src.dir = "."){
   
   file <- match.arg(file, file.names, several.ok=FALSE)
   
-  rfl1 <- utils::read.table(file = paste0(src.dir,"/",file), nrows = 1)[1,1]
+  rfl1 <- utils::read.table(file = file.path(src.dir, file), nrows = 1)[1,1]
   ## The next line will work if all XML files contain xml in the first line
   if(length(grep("xml", as.character(rfl1))) != 0){
     ans <- "xml"
