@@ -199,7 +199,7 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   
   rep.node.subchildren.names <- vapply(rep.node.child$Children, function(x) x$Name,
                                        FUN.VALUE = "character")
-  wrnsc <- grep(node.subchild, rep.node.subchildren.names)
+  wrnsc <- grep(node.subchild, rep.node.subchildren.names, fixed = gfixed, ignore.case = gignore.case)
   if(length(wrnsc) == 0) stop("node.subchild not found")
   if(length(wrnsc) > 1) stop("More than one subchild found. Make it unique (see regular expressions)")
   rep.node.subchild <- rep.node.child$Children[[wrnsc]]
@@ -233,7 +233,7 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   ## unnamed Children
   rep.node.subsubchildren.names <- vapply(rep.node.subchild$Children, function(x) x$Name,
                                           FUN.VALUE = "character")
-  wrnssc <- grep(node.subsubchild, rep.node.subsubchildren.names)
+  wrnssc <- grep(node.subsubchild, rep.node.subsubchildren.names, fixed = gfixed, ignore.case = gignore.case)
   if(length(wrnssc) == 0) stop("node.subsubchild not found")
   if(length(wrnssc) > 1) stop("More than one subsubchild found. Make it unique (see regular expressions)")
   rep.node.subsubchild <- rep.node.subchild$Children[[wrnssc]]
@@ -276,12 +276,12 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   }
   
   if(!is.null(parm) && any(parm %in% rep.node.subsubchild.names)){
-      wrnsspc <- grep(parm, rep.node.subsubchild.names)
+      wrnsspc <- grep(parm, rep.node.subsubchild.names, fixed = gfixed, ignore.case = gignore.case)
       rep.node.sub3child <- rep.node.subsubchild[wrnsspc]
       cat_parm(rep.node.sub3child, parm = parm)
   }else{
     if(!is.null(parm) && any(grepl(parm, unlist(rep.node.subsubchild$Command)))){
-      wcp <- grep(parm, unlist(rep.node.subsubchild$Command))
+      wcp <- grep(parm, unlist(rep.node.subsubchild$Command), fixed = gfixed, ignore.case = gignore.case)
       cat(unlist(rep.node.subsubchild$Command)[wcp], "\n")
     }else{
       if(!is.null(parm) && missing(node.sub3child)) stop("Parameter not found")
@@ -300,7 +300,7 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   
   rep.node.sub3children.names <- vapply(rep.node.subsubchild$Children, function(x) x$Name,
                                        FUN.VALUE = "character")
-  wrnsssc <- grep(node.sub3child, rep.node.sub3children.names)
+  wrnsssc <- grep(node.sub3child, rep.node.sub3children.names, fixed = gfixed, ignore.case = gignore.case)
   if(length(wrnsssc) == 0) stop("node.sub3child not found")
   if(length(wrnsssc) > 1) stop("More than one sub3child found. Make it unique (see regular expressions)")
   rep.node.sub4child <- rep.node.subsubchild$Children[[wrnsssc]]
@@ -342,7 +342,7 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   }
   
   if(!is.null(parm) && any(grepl(parm, rep.node.sub4child.names))){
-    wrnssspc <- grep(parm, rep.node.sub4child.names)
+    wrnssspc <- grep(parm, rep.node.sub4child.names, fixed = gfixed, ignore.case = gignore.case)
     rep.node.sub4child <- rep.node.sub4child[wrnssspc]
     cat_parm(rep.node.sub4child, parm = parm) ## This might be wrong, without parm argument
   }else{
@@ -471,7 +471,7 @@ inspect_apsimx_replacement <- function(file = "", src.dir = ".",
   }  
   
   if(!is.null(parm) && any(grepl(parm, rep.node.sub6child.names))){
-    wrnssssspc <- grep(parm, rep.node.sub6child.names)
+    wrnssssspc <- grep(parm, rep.node.sub6child.names, fixed = gfixed, ignore.case = gignore.case)
     rep.node.sub6child <- rep.node.sub5child[wrnssssspc]
     cat_parm(rep.node.sub6child, parm = parm) ## This might be wrong, without parm argument
   }else{
